# mctl
mctl is a terminal-friendly remote console client

# Index
1. [Installation](#installation)
2. [Setup](#setup)
3. [Documentation](#documentation)
4. [Security](#security)
5. [Development](#development)

<br />

# Installation
Install mctl using golang
```bash
go install code.jakeyoungdev.com/jake/mctl@main #it is recommended to use a tagged version
```

<br />

# Setup
### Configuring mctl
mctl requires a one-time setup via the 'config' command before interacting with any servers, password is entered securely from the terminal and encrypted
```bash
mctl config -s <serveraddress> -p <rconport>
```

### Connecting to server
Once the client has been configured commands can be sent to the server using the 'login' command. This will authenticate you with the game server and enter the command loop, the session is logged out when the command loop is broken

```bash
mctl login #makes auth request to server with saved password
```

### Sending commands
If login is successful the app will enter the command loop, which allows commands to be sent directly to the server. Commands are sent as-is to the server, there is no validation of command syntax within mctl
```
Logging into X.X.X.X on port 61695
Connected! Type 'mctl' to close
RCON@X.X.X.X /> list

There are 0 of a max of 20 players online:
```

### Saving commands
Commands can be saved under an alias for quick execution later, saved commands can contain placeholders '%s' that can be populated at runtime to allow for commands with unique runtime args to still be saved, see [example](#saving-and-running-example) for more:
```bash
mctl save <name>
```

### Viewing commands
Saved commands can be viewed with:
```bash
mctl view <name>
```
All saved commands can be viewed with:
```bash
mctl view all
```

### Running saved commands
Commands that have been saved can be run with:
```bash
mctl run <name>
```
If the saved command contains placeholders, the necessary arguments must be supplied:
```bash
mctl run <name> args...
```

### Saving and running example
```bash
#saving command named "test" to run "tp %s 0 0 0"
mctl save test
Command: tp %s 0 0 0

#run command on user "jake"
mctl run test jake
#will run: tp jake 0 0 0 on remote server
```

### Delete saved command
Commands can be deleted with:
```bash
mctl delete <name>
```

### Clear configuration file
To clear all fields from the configuration file use:
```bash
#CAUTION: If the config file is cleared all data previously saved will be lost forever
mctl clear
```

<br />

# Documentation
### Commands
|Command|Description|
|---|---|
|config|used to update the config file|
|login|makes connection request to the server using saved configuration and enters command loop|
|save \<name>|saves specific command for reuse|
|view \<name>|displays saved command|
|delete \<name>|deletes saved command|
|run \<name> args...|runs saved command filling placeholders with supplied args|
|clear|clears config file|

### Configuration file
All configuration data will be kept in the home directory and any sensitive data is encrypted for added security

<br />

# Security
RCon is an inherently insecure protocol, passwords are sent in plaintext and, if possible, the port should not be exposed to the internet. It is best to keep these connections local or over a VPN.

mctl utilizes [govulncheck](https://pkg.go.dev/golang.org/x/vuln/cmd/govulncheck) and [gosec](https://github.com/securego/gosec) in workflows to ensure quality, secure code is being pushed. These workflow steps must pass before a PR will be accepted

<br />

# Development
this repo is currently in development and may encounter breaking changes, use a tag to prevent any surprises

# TODO
1. continue sqlite update
2. migrate the credentials to sqlite as well
3. login too
4. MCR client also has viper stuff, gut it
5. Since we are now using sqlite should we just encode the pwd and insert